xonsh
=====

.. image:: https://travis-ci.org/scopatz/xonsh.svg?branch=master
    :target: https://travis-ci.org/scopatz/xonsh

.. image:: https://landscape.io/github/scopatz/xonsh/master/landscape.svg?style=flat
    :target: https://landscape.io/github/scopatz/xonsh/master
    :alt: Code Health

xonsh is a Python-ish, BASHwards-compatible shell language and command prompt.
The language is a superset of Python 3.4 with additional shell primitives.
xonsh (pronounced *conch*) is meant for the daily use of experts and novices 
alike.

Please visit http://xonsh.org for more information.
